for k=1:100,  % for all stimuli in the chosen database
    % Choose one of the sets below (edited or original) 
    filen=[filenames{k},'e']; % reads filenames of the signals in the
    
[x,fs]=wavread(filen);   % reads wavfile
fsd=1200;   % new sampling rate
% Enforces a given percentage of amplitude clipping in the voice-active regions 
if p_clip>0, % runs if the percentage of clip is greater than 0
    xds=resample(x,100,3675,20); % signal ressampling
    [vad,ind0,ind1]=vad_v3(xds,fsd,p1,p2); % estimate voice-active regions at the low fs
    vad=resample(vad,3675,100,0); vad=vad(1:length(x));  % vad back in the original fs
    x=wf_clipper2(x,p_clip,vad); % function that enforces clipping   
end

xds=resample(x,100,3675,20); % downsampling from 44.1 Hz to 1200 Hz  
clear x vad

[vad_xds,ind0d,ind1d]=vad_v3(xds,fsd,p1,p2);  % estimate voice-active regions at the low fs 
vad_xds=vad_xds(br:end-br-1); % removes transients 

xds_f=filtfilt(b,a,xds); % bandpass filters (around 60Hz) the downsampled signal 
z=hilbert(xds_f);  % calculates the analytic signal associated with xds_f
f=phase(z(2:end,:).*conj(z(1:end-1,:)));  % Hilbert estimate of the instantaneous frequency of xds_f  
clear z xds xds_f

f=f-median(f(br:end-br));  % removes median value from the instananeous frequency of xds_f 
% Here we are interested only in the variations of f 
f=filtfilt(b20,a20,f); % lowpass filters f (20Hz passband) to remove the 60 Hz oscillations that leaks into the Hilbert estimate

mf=abs(f); % takes the magnitude of the processed f
% mf should display moderate magnitude bumbs for unedited signals and high
% level peaks when editing (or strong saturation) occurs 
vm_f=tpswma_new2(mf,length(mf),600,150,2); % calculates a variable thrshold for mf via TPSW filtering 
f=f(br:end-br);

mf=mf(br:end-br); % removes boundary transients in mf 
vm_f=vm_f(br:end-br); % removes boundary transients in vm_f 

thr_mf=vm_f+TG*median(vm_f); % computes threshold for mf
% The threshold is contructed as vm_f plus an offset that lifts the whole variable threshold to 5.5
% times its median 
clear vm_f

mf_hthr=mf.*(mf>=thr_mf); % hard-thresholded mf
mf_hthr=mf_hthr.*~vad_xds; % only considers peaks of mf_hthr that are outside the VAD regions 
idxmax_mft=find_local_maxima(mf_hthr);  % finds local maxima in the thresholded mf
len_idxmax=length(idxmax_mft);  % number of local maxima (above the threshold)

% runs the cross-correlation coefficient test for all found local maxima
if ~isempty(idxmax_mft),
    % All local maxima above the thresholds are verified by template
    % matching to assure it is indeed due to an edit
    templ_det=zeros(1,len_idxmax);
    for m=1:len_idxmax,
        % for each local maxima above the threshold defines a range for
        % verification
        rgv_min=max(1,idxmax_mft(m)-len_FI_tpl);
        rgv_max=min(length(mf),idxmax_mft(m)+len_FI_tpl);
        rg_verif=rgv_min:rgv_max;
        % runs the template matching against two templates: FI_templ and
        % fp5 and takes the maximum correlation coefficient between them
        templ_det(m)=max(template_matching_new(f(rg_verif),FI_templ),template_matching_new(f(rg_verif),fp5));
        % function template_matching.m returns the maximum correlation coefficient between the two input signals  
    end
    % a given signal may have several local maxima, thus we take the
    % maximum of the set of correlation coefficients associated with each
    % local maximum
    max_templ_det=max(templ_det);
    if max_templ_det >= lambda,  % if the maximum corr. coeff is above lambda then we consider a hit (an edit ocurred)
        det_status='hit';
        counter_hit=counter_hit+1;
    else
        det_status='miss';
        counter_miss=counter_miss+1;
    end    
else
    det_status='miss'; % miss when there is no local maxima above the threshold 
    counter_miss=counter_miss+1;
end
end
