clc; close all; clear all

addpath('F:\Forense\base_carioca')  % add the path to the Carioca 1 database
% Loads excel table with the filenames of the wav files and the cut/insert
% time in samples
[cortes,filenames]=xlsread('Edicoes_base_carioca.xls');  % loads edit annotations  

screen_size = get(0, 'ScreenSize');

% Loads filter coefficients 
load filter_60Hz_1p4Hz_4th  % loads filter coeff. a and b (elliptic bandpass centered at 60 Hz)
load filter_PB20_20Hz_5th % b20 a20 (elliptic lowpass filter with 20Hz passband and zero at 60 Hz)

p1=150; % minimum duration of a mute (in ms)
p2=60; % minimum duration of a utterance (in ms)

br=2000; % number of samples to be discarded in the beginning and end of the detection signals (due to trasnsients) 

load FI_temp_p4; % loads fp4: a template for the variation in the instantaneous frequency due to an edit 
% in which 40% of a 60Hz cycle has been removed from the signal  
load FI_temp_p5; % loads fp5: same as above but for removal of 50% of a 60 Hz cycle

FI_templ=fp4;   % stores FI variation template 
len_FI_tpl=length(FI_templ);
TP=0; FP=0; FN=0;   % initial counters for True detection, false posisives, and false negatives
lambda=0.7;   % value of lambda used in the detection criterion

p_clip=0;   % set the percentage of amplitude clipped samples in the active voice regions
TGv=2.9:0.1:3.5; % set of TG (G in the paper) values    

% uncomment the two lines below to run the experiment for 4% of clipped
% samples
% p_clip=4;   % set the percentage of amplitude clipped samples in the active voice regions
% TGv=9.6:0.1:10.5; % set of TG (G in the paper) values    


MR=zeros(length(TGv),5); % Matrix to store the results 
cc=1;  % counter 
disp(['TMVAD_CARIOCA 1 - CLIP ',num2str(p_clip),'%',' lambda = ',num2str(lambda)])
disp(['     TG ', '       TP ', '         FP ', '        FN '])
for TG=TGv,
    counter_hit=0;  % set counter of number of hits (any edit detection) to zero
    counter_miss=0; % set counter of number of misses (no edit detection) to zero
    core_TMVAD_CLIP_noEdit_Car  % runs detection method for the subset of unedited signals
    FP=counter_hit; % stores as false posistives the number of edits found in the set of unedited signals  
    counter_hit=0; % set counter of number of hits (any edit detection) to zero 
    counter_miss=0; % set counter of number of misses (no edit detection) to zero
    core_TMVAD_CLIP_Edit_Car % runs the edit detection method for the subset of edited signals
    TP=counter_hit; % stores as true positives the number of edits found in the set of edited signals  
    FN=counter_miss; % stores as false negatives the number of misses found in the subset of edited signals
    mydisp(round([TG TP FP FN].*10)./10)
    MR(cc,:)=[TG TP FP FN abs(FP-FN)];  % stores the results in the MR matrix
    cc=cc+1; % udated the counter
end

% saves the attained results
id_save=['TMVAD_CARIOCA1_CLIP_',num2str(p_clip),'_lam_d',num2str(1000*lambda),'_rd1'];
eval(['save ',id_save,' MR lambda p_clip'])
xlswrite(id_save, MR)

% Summary of the results
aux=MR(:,5);
plot(TGv,aux); xlabel('TG'); ylabel('abs(FP-FN)') 
mm=min(aux);
indmm=find(aux==mm);
EER=MR(indmm(end),:) % display EER condition  

