function mx=tpswma_new2(x,npts,n,p,a)
% |
% |[mx] = tpsw(x,npts,n,p,a)
% |
% | Claculates a local median estimate for the vector x using the 
% |"two-pass split window" algorithm
% |
% | where:	x	= input vector
% |		npts	= number of points in x to be processed
% |		n	= half of the length of the window 
% |		p	= half of the length of the central gap
% |		a	= constant for the threshold computation
% |
% |		mx	= output vector
% |________________________________________________________
% |

% Based on the original program by 

% |William Soares-Filho
% |Instituto de Pesquisas da Marinha, RJ- Brazil

% Last modified: 13th August, 2010

% Input arguments checking
%
if nargin<1,help tpsw;return;end	% show help (without arguments)
if min(size(x))==1,x=x(:);end		% change input vector to column form
if nargin<2,npts=size(x,1);end		% length of the input vector
x=x(1:npts,:);
if nargin<3,n=round(npts*.04/2+1);end	% length of the window
if nargin<4,p=round(n/8+1);end		% length of the central gap
if nargin<5,a=2.0;end			% constant for the threshold calculus

% First pass using the gapped window
%
h=[ones(1,n-p+1) zeros(1,2*p-1) ones(1,n-p+1)];	% sets the filter
h=h(:); h=h/norm(h,1);	% normalization

%%%%%%%%%
x=x(:); Lx=length(x); Lxe=n; %round(.1*length(x));
% extend the bondaries:
ini_x=flipud(x(1:Lxe));
end_x=x(end-(0:(Lxe-1)));
x=[ini_x;x;end_x];

% x=x(:); Lx=length(x); Lxe=n; %round(.1*length(x));
% % extend the bondaries:
% ini_x=flipud(x(1:Lxe));
% end_x=x(end-(0:(Lxe-1)));
% x=[-ini_x(1:end-1)+2*x(1);x;-end_x(2:end)+2*x(end)];

%plot(x); pause; close

mx=filter2(h,x,'same');



% Peak removal before second pass
%ind1=find(abs(x-mx)>abs(mx-a*mx));
ind1=find(x>a*mx);
x(ind1)=mx(ind1);				

% second pass using window without the central gap
h2=ones(length(h),1); h2=h2/norm(h2,1);	
mx=filter2(h2,x,'same');
%mx=mx(round(1.5*Lxe)+(1:Lx));
mx=mx(round(1.0*Lxe)+(1:Lx));

